@@ -57,20 +57,30 @@ def settings(
     defaultChecked: bool=False,
     delay: Optional[int]=500,
     key: str =None) -> str:
-    """Send settings to a CAD software.
+    """Send/get settings to/from a CAD software.
 
     Parameters
     ----------
-    data: dict
-        A ladybug geometry dictionary with the settings.
-        Example.
-        
+    data: dict or string. Dict to SET settings. String to GET settings.
+
+        String MUST start with 'SETTINGS' keyword. You can use 'special.sync' output
+        to generate a token when you change document info of the host software automatically.
+
+        Dict MUST have following schema:
         data = {
                 'earth_anchor': {
                     'lat': 41.2324,
                     'lon': 12.3234
-                }
+                },
+                units: 1
             }
+        
+        - Where Units mapping:
+            - Millimeter = 2
+            - Centimeter = 3
+            - Meters = 4
+            - Inches = 8
+            - Feet = 9
 
     defaultChecked: bool
         Set if it has to be checked by default.
@@ -80,6 +90,10 @@ def settings(
         An optional key that uniquely identifies this component. If this is
         None, and the component's arguments are changed, the component will
         be re-mounted in the Streamlit frontend and lose its current state.
+    
+    return:
+        if String as 'data' it returns JSON settings inside streamlit
+        because it is in GET mode. Otherwise nothing.
     """
     component_value = _component_func_settings(
         data=data,
@@ -87,6 +101,22 @@ def settings(
         delay=delay,
         key=key, 
         default=None)
+    
+    units = {
+        2: 'Millimeter',
+        3: 'Centimeter',
+        4: 'Meters',
+        8: 'Inches',
+        9: 'Feet'
+    }
+
+    if component_value:
+        out_unit = component_value.get('units')
+        if not out_unit:
+            return component_value
+        
+        component_value = { **component_value, 
+            **{'units': units.get(out_unit)} }
 
     return component_value
 
@@ -102,4 +132,18 @@ if not _RELEASE:
     
     sync_token_2 = sync(defaultChecked=True, 
         key='my-secret-key-2')
-    st.write(sync_token_2)
\ No newline at end of file
+    st.write(sync_token_2)
+
+
+    data = {
+            'earth_anchor': {
+                'lat': 41.2324,
+                'lon': 12.3234
+            },
+            'units': 2
+        }
+
+    test = settings(
+        data=sync_token_2,
+        defaultChecked=True)
+    st.write(test)
\ No newline at end of file
